/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.isobus.model;

/**
 * Describes the dataTypes of the ISO 17783-10 PTN element in the binary file  
 * @author Gerben Feenstra
 */
public enum PositionFieldEnum implements XmlField {

    /** PTN A **/
    POSITION_NORTH("A", BinaryDataType.BIT32_SIGNED),
    /** PTN B **/
    POSITION_EAST("B", BinaryDataType.BIT32_SIGNED),
    /** PTN C **/
    POSITION_UP("C", BinaryDataType.BIT32_SIGNED),
    /** PTN D **/
    POSITION_STATUS("D", BinaryDataType.BIT8_SIGNED),
    /** PTN E **/
    POSITION_PDOP("E", BinaryDataType.BIT16_UNSIGNED),
    /** PTN F **/
    POSITION_HDOP("F", BinaryDataType.BIT16_UNSIGNED),
    /** PTN G **/
    POSITION_SAT_NR("G", BinaryDataType.BIT8_SIGNED),
    /** PTN H **/
    POSITION_GPS_UTC_TIME("H", BinaryDataType.BIT32_UNSIGNED),
    /** PTN I **/
    POSITION_GPS_UTC_DATE("I", BinaryDataType.BIT16_UNSIGNED);
    
    String xmlField = "";
    BinaryDataType dataType = null;

    PositionFieldEnum(String xmlField, BinaryDataType dataType) {
        this.xmlField = xmlField;
        this.dataType = dataType;
    }

    @Override
    public String getAttributeName() {
        return xmlField;
    }

    @Override
    public BinaryDataType getDataType() {
        return dataType;
    }
}
